@@ -12,7 +12,7 @@ static Ecore_Event_Handler *_e_dpms_handler_desk_show = NULL;
 static unsigned int _e_dpms_timeout_standby = 0;
 static unsigned int _e_dpms_timeout_suspend = 0;
 static unsigned int _e_dpms_timeout_off = 0;
-static int _e_dpms_enabled = EINA_FALSE;
+static int _e_dpms_enabled = -1;
 E_API Eina_Bool e_dpms_actual = EINA_FALSE;
 
 #ifdef HAVE_WAYLAND
@@ -43,15 +43,19 @@ e_dpms_update(void)
                {
                   ecore_x_dpms_enabled_set(enabled);
                   e_dpms_actual = enabled;
+                 if (_e_dpms_enabled) fprintf(stderr, "DPMS: on\n");
+                 else fprintf(stderr, "DPMS: off\n");
                }
              else
                {
                   ecore_x_dpms_enabled_set(0);
                   e_dpms_actual = EINA_FALSE;
+                 fprintf(stderr, "DPMS: off\n");
                }
           }
 #endif
      }
+   else fprintf(stderr, "DPMS: unchanged (%s)\n", enabled ? "on" : "off");
    if (!enabled) return;
 
    if (e_config->screensaver_enable)
