@@ -330,39 +330,44 @@ e_remember_apply(E_Remember *rem, E_Client *ec)
                e_desk_show(desk);
           }
      }
+   if (rem->apply & E_REMEMBER_APPLY_BORDER)
+     {
+        eina_stringshare_replace(&ec->bordername, NULL);
+        ec->bordername = eina_stringshare_ref(rem->prop.border);
+        ec->border.changed = 1;
+        EC_CHANGED(ec);
+     }
    if (rem->apply & E_REMEMBER_APPLY_SIZE)
      {
         int w, h;
+        int uzx = 0, uzy = 0, uzw = 0, uzh = 0;
+
+        e_zone_useful_geometry_get(ec->zone, &uzx, &uzy, &uzw, &uzh);
 
         w = ec->client.w;
         h = ec->client.h;
-        if (rem->prop.pos_w)
-          ec->client.w = rem->prop.pos_w;
-        if (rem->prop.pos_h)
-          ec->client.h = rem->prop.pos_h;
-        /* we can trust internal windows */
-        if (ec->internal)
+        if (rem->prop.pos_w) ec->client.w = rem->prop.pos_w;
+        if (rem->prop.pos_h) ec->client.h = rem->prop.pos_h;
+        if (uzw != rem->prop.res_x)
           {
-             if (ec->zone->w != rem->prop.res_x)
-               {
-                  if (ec->client.w > (ec->zone->w - 64))
-                    ec->client.w = ec->zone->w - 64;
-               }
-             if (ec->zone->h != rem->prop.res_y)
-               {
-                  if (ec->client.h > (ec->zone->h - 64))
-                    ec->client.h = ec->zone->h - 64;
-               }
-             if (ec->icccm.min_w > ec->client.w)
-               ec->client.w = ec->icccm.min_w;
-             if ((ec->icccm.max_w > 0) && (ec->icccm.max_w < ec->client.w))
-               ec->client.w = ec->icccm.max_w;
-             if (ec->icccm.min_h > ec->client.h)
-               ec->client.h = ec->icccm.min_h;
-             if ((ec->icccm.max_h > 0) && (ec->icccm.max_h < ec->client.h))
-               ec->client.h = ec->icccm.max_h;
+             if (ec->client.w > (uzw - rem->prop.frame_w))
+               ec->client.w = uzw - rem->prop.frame_w;
           }
-        e_comp_object_frame_wh_adjust(ec->frame, ec->client.w, ec->client.h, &ec->w, &ec->h);
+        if (uzh != rem->prop.res_y)
+          {
+             if (ec->client.h > (uzh - rem->prop.frame_h))
+               ec->client.h = uzh - rem->prop.frame_h;
+          }
+        if (ec->icccm.min_w > ec->client.w)
+          ec->client.w = ec->icccm.min_w;
+        if ((ec->icccm.max_w > 0) && (ec->icccm.max_w < ec->client.w))
+          ec->client.w = ec->icccm.max_w;
+        if (ec->icccm.min_h > ec->client.h)
+          ec->client.h = ec->icccm.min_h;
+        if ((ec->icccm.max_h > 0) && (ec->icccm.max_h < ec->client.h))
+          ec->client.h = ec->icccm.max_h;
+        e_comp_object_frame_wh_adjust(ec->frame, ec->client.w, ec->client.h,
+                                      &ec->w, &ec->h);
         if (rem->prop.maximize)
           {
              ec->saved.x = rem->prop.pos_x;
@@ -381,93 +386,100 @@ e_remember_apply(E_Remember *rem, E_Client *ec)
      }
    if ((rem->apply & E_REMEMBER_APPLY_POS) && (!ec->re_manage))
      {
+        int uzx = 0, uzy = 0, uzw = 0, uzh = 0;
+
+        e_zone_useful_geometry_get(ec->zone, &uzx, &uzy, &uzw, &uzh);
         ec->x = rem->prop.pos_x;
         ec->y = rem->prop.pos_y;
-        if (ec->zone->w != rem->prop.res_x)
+        if (uzw != rem->prop.res_x)
           {
              int px;
 
-             px = ec->x + (ec->w / 2);
-             if (px < ((rem->prop.res_x * 1) / 3))
+             px = uzw - (ec->w + rem->prop.frame_w);
+             if (px < 1) px = 0;
+             else px = (3 * ec->x) / px;
+             if (px < 1)
                {
-                  if (ec->zone->w >= (rem->prop.res_x / 3))
+                  if (uzw >= (rem->prop.res_x / 3))
                     ec->x = rem->prop.pos_x;
                   else
-                    ec->x = ((rem->prop.pos_x - 0) * ec->zone->w) /
+                    ec->x = ((rem->prop.pos_x - 0) * uzw) /
                       (rem->prop.res_x / 3);
                }
-             else if (px < ((rem->prop.res_x * 2) / 3))
+             else if (px == 1)
                {
-                  if (ec->zone->w >= (rem->prop.res_x / 3))
-                    ec->x = (ec->zone->w / 2) +
+                  if (uzw >= (rem->prop.res_x / 3))
+                    ec->x = (uzw / 2) +
                       (px - (rem->prop.res_x / 2)) -
                       (ec->w / 2);
                   else
-                    ec->x = (ec->zone->w / 2) +
-                      (((px - (rem->prop.res_x / 2)) * ec->zone->w) /
+                    ec->x = (uzw / 2) +
+                      (((px - (rem->prop.res_x / 2)) * uzw) /
                        (rem->prop.res_x / 3)) -
                       (ec->w / 2);
                }
-             else
+             else // >= 2
                {
-                  if (ec->zone->w >= (rem->prop.res_x / 3))
-                    ec->x = ec->zone->w +
+                  if (uzw >= (rem->prop.res_x / 3))
+                    ec->x = uzw +
                       rem->prop.pos_x - rem->prop.res_x +
                       (rem->prop.w - ec->client.w);
                   else
-                    ec->x = ec->zone->w +
-                      (((rem->prop.pos_x - rem->prop.res_x) * ec->zone->w) /
+                    ec->x = uzw +
+                      (((rem->prop.pos_x - rem->prop.res_x) * uzw) /
                        (rem->prop.res_x / 3)) +
                       (rem->prop.w - ec->client.w);
                }
              if ((rem->prop.pos_x >= 0) && (ec->x < 0))
                ec->x = 0;
              else if (((rem->prop.pos_x + rem->prop.w) < rem->prop.res_x) &&
-                      ((ec->x + ec->w) > ec->zone->w))
-               ec->x = ec->zone->w - ec->w;
+                      ((ec->x + ec->client.w + rem->prop.frame_w) > (uzw - (uzx - ec->zone->x))))
+               ec->x = (uzw - (uzx - ec->zone->x)) - ec->client.w - rem->prop.frame_w;
           }
-        if (ec->zone->h != rem->prop.res_y)
+        if (uzh != rem->prop.res_y)
           {
              int py;
 
-             py = ec->y + (ec->h / 2);
-             if (py < ((rem->prop.res_y * 1) / 3))
+             py = uzh - (ec->h + rem->prop.frame_h);
+             if (py < 1) py = 0;
+             else py = (3 * ec->y) / py;
+             if (py < 1)
                {
-                  if (ec->zone->h >= (rem->prop.res_y / 3))
+                  if (uzh >= (rem->prop.res_y / 3))
                     ec->y = rem->prop.pos_y;
                   else
-                    ec->y = ((rem->prop.pos_y - 0) * ec->zone->h) /
+                    ec->y = ((rem->prop.pos_y - 0) * uzh) /
                       (rem->prop.res_y / 3);
                }
-             else if (py < ((rem->prop.res_y * 2) / 3))
+             else if (py == 1)
                {
-                  if (ec->zone->h >= (rem->prop.res_y / 3))
-                    ec->y = (ec->zone->h / 2) +
+                  if (uzh >= (rem->prop.res_y / 3))
+                    ec->y = (uzh / 2) +
                       (py - (rem->prop.res_y / 2)) -
                       (ec->h / 2);
                   else
-                    ec->y = (ec->zone->h / 2) +
-                      (((py - (rem->prop.res_y / 2)) * ec->zone->h) /
+                    ec->y = (uzh / 2) +
+                      (((py - (rem->prop.res_y / 2)) * uzh) /
                        (rem->prop.res_y / 3)) -
                       (ec->h / 2);
                }
-             else
+             else // >= 2
                {
-                  if (ec->zone->h >= (rem->prop.res_y / 3))
-                    ec->y = ec->zone->h +
+                  if (uzh >= (rem->prop.res_y / 3))
+                    ec->y = uzh +
                       rem->prop.pos_y - rem->prop.res_y +
                       (rem->prop.h - ec->client.h);
                   else
-                    ec->y = ec->zone->h +
-                      (((rem->prop.pos_y - rem->prop.res_y) * ec->zone->h) /
+                    ec->y = uzh +
+                      (((rem->prop.pos_y - rem->prop.res_y) * uzh) /
                        (rem->prop.res_y / 3)) +
                       (rem->prop.h - ec->client.h);
                }
              if ((rem->prop.pos_y >= 0) && (ec->y < 0))
                ec->y = 0;
              else if (((rem->prop.pos_y + rem->prop.h) < rem->prop.res_y) &&
-                      ((ec->y + ec->h) > ec->zone->h))
-               ec->y = ec->zone->h - ec->h;
+                      ((ec->y + ec->client.h + rem->prop.frame_h) > (uzh - (uzy - ec->zone->y))))
+               ec->y = (uzh - (uzy - ec->zone->y)) - ec->client.h - rem->prop.frame_h;
           }
         //		  if (ec->zone->w != rem->prop.res_x)
         //		    ec->x = (rem->prop.pos_x * ec->zone->w) / rem->prop.res_x;
@@ -485,10 +497,11 @@ e_remember_apply(E_Remember *rem, E_Client *ec)
           )
           {
              e_comp_object_util_center_pos_get(ec->frame, &ec->x, &ec->y);
-             rem->prop.pos_x = ec->x, rem->prop.pos_y = ec->y;
+             rem->prop.pos_x = ec->x;
+             rem->prop.pos_y = ec->y;
           }
-        ec->x += ec->zone->x;
-        ec->y += ec->zone->y;
+        ec->x += uzx;
+        ec->y += uzy;
         ec->placed = 1;
         ec->changes.pos = 1;
         EC_CHANGED(ec);
@@ -497,13 +510,6 @@ e_remember_apply(E_Remember *rem, E_Client *ec)
      {
         evas_object_layer_set(ec->frame, rem->prop.layer);
      }
-   if (rem->apply & E_REMEMBER_APPLY_BORDER)
-     {
-        eina_stringshare_replace(&ec->bordername, NULL);
-        ec->bordername = eina_stringshare_ref(rem->prop.border);
-        ec->border.changed = 1;
-        EC_CHANGED(ec);
-     }
    if (rem->apply & E_REMEMBER_APPLY_FULLSCREEN)
      {
         if (rem->prop.fullscreen)
@@ -718,23 +724,30 @@ _e_remember_update(E_Client *ec, E_Remember *rem)
    if (rem->apply & E_REMEMBER_APPLY_POS ||
        rem->apply & E_REMEMBER_APPLY_SIZE)
      {
+        int uzx = 0, uzy = 0, uxw = 0, uzh = 0;
+
+        e_zone_useful_geometry_get(ec->zone, &uzx, &uzy, &uxw, &uzh);
         if (ec->fullscreen || ec->maximized)
           {
-             rem->prop.pos_x = ec->saved.x;
-             rem->prop.pos_y = ec->saved.y;
+             rem->prop.pos_x = ec->saved.x - uzx;
+             rem->prop.pos_y = ec->saved.y - uzy;
              rem->prop.pos_w = ec->saved.w;
              rem->prop.pos_h = ec->saved.h;
+             rem->prop.frame_w = ec->w - ec->client.w;
+             rem->prop.frame_h = ec->h - ec->client.h;
           }
         else
           {
-             rem->prop.pos_x = ec->x - ec->zone->x;
-             rem->prop.pos_y = ec->y - ec->zone->y;
-             rem->prop.res_x = ec->zone->w;
-             rem->prop.res_y = ec->zone->h;
+             rem->prop.pos_x = ec->x - uzx;
+             rem->prop.pos_y = ec->y - uzy;
+             rem->prop.res_x = uxw;
+             rem->prop.res_y = uzh;
              rem->prop.pos_w = ec->client.w;
              rem->prop.pos_h = ec->client.h;
              rem->prop.w = ec->client.w;
              rem->prop.h = ec->client.h;
+             rem->prop.frame_w = ec->w - ec->client.w;
+             rem->prop.frame_h = ec->h - ec->client.h;
           }
         rem->prop.maximize = ec->maximized & E_MAXIMIZE_DIRECTION;
      }
