@@ -27,7 +27,6 @@ typedef struct _Config Config;
 struct _Config
 {
    /* saved / loaded config values */
-   int                  poll_interval;
    int                  alert;          /* Alert on minutes remaining */
    int                  alert_p;        /* Alert on percentage remaining */
    int                  alert_timeout;  /* Popup dismissal timeout */
@@ -61,19 +60,49 @@ struct _Config
 
 typedef struct _Battery Battery;
 typedef struct _Ac_Adapter Ac_Adapter;
+typedef struct _Battery_Hist Battery_Hist;
+typedef struct _Battery_Hist_Entry Battery_Hist_Entry;
+
+#define BATTERY_HIST_MAX 1000
+struct _Battery_Hist_Entry
+{
+  unsigned long long timepoint; // time_t
+  unsigned short     full; // 0-10000 = 0->100%
+  unsigned short     power_now ; // 1unit = 0.1w
+  unsigned short     ac : 1;
+  unsigned short     charging : 1;
+  unsigned short     pad : 14; // 14 bits to pad out rest of short
+  unsigned short     pad2 ; // pad out rest of struct
+}; // 16 bytes
+
+struct _Battery_Hist
+{
+#define BATTERY_HISTORY_MAGIC 0xfeedee77
+  unsigned int       magic; // BATTERY_HISTORY_MAGIC
+#define BATTERY_HISTORY_VERSION 100
+  unsigned short     version; // BATTERY_HISTORY_VERSION
+  unsigned short     history_pos; // if >= BATTERY_HIST_MAX reset to 0
+  int                pad;
+  int                pad2;
+  // no padding needed (16 byte header) as we're aligned
+  Battery_Hist_Entry history[BATTERY_HIST_MAX];
+};
 
 struct _Battery
 {
    const char   *udi;
 #if defined HAVE_EEZE || defined __OpenBSD__ || defined __DragonFly__ || defined __FreeBSD__ || defined __NetBSD__
-   Ecore_Poller *poll;
+   Ecore_Timer  *timer;
    Eina_Bool     present E_BITFIELD;
    Eina_Bool     charging E_BITFIELD;
+   Eina_Bool     is_micro_watts E_BITFIELD;
    double        last_update;
    double        percent;
+   double        power_now;
    double        current_charge;
    double        design_charge;
    double        last_full_charge;
+   double        design_voltage;
    double        charge_rate;
    double        time_full;
    double        time_left;
@@ -88,9 +117,11 @@ struct _Battery
    const char   *type;
    const char   *charge_units;
 #endif
+   Battery_Hist *hist;
    const char   *technology;
    const char   *model;
    const char   *vendor;
+   int           history_power_now_max;
    Eina_Bool     got_prop E_BITFIELD;
    Eldbus_Proxy *proxy;
 #if defined __FreeBSD__ || defined __DragonFly__
@@ -118,6 +149,9 @@ Battery    *_battery_battery_find(const char *udi);
 Ac_Adapter *_battery_ac_adapter_find(const char *udi);
 void        _battery_device_update(void);
 
+void        _battery_history_load(Battery *bat);
+void        _battery_history_close(Battery *bat);
+
 #ifdef HAVE_EEZE
 /* in e_mod_udev.c */
 int         _battery_udev_start(void);
