@@ -62,9 +62,7 @@ _battery_sysctl_start(void)
              bat->technology = eina_stringshare_add("Unknown");
              bat->model = eina_stringshare_add("Unknown");
              bat->vendor = eina_stringshare_add("Unknown");
-             bat->poll = ecore_poller_add(ECORE_POLLER_CORE,
-                                          battery_config->poll_interval,
-                                          _battery_sysctl_battery_update_poll, NULL);
+             bat->timer = ecore_timer_add(10.0, _battery_sysctl_battery_update_poll, NULL);
              device_batteries = eina_list_append(device_batteries, bat);
           }
         else if (!strcmp("acpiac0", snsrdev.xname))
@@ -107,9 +105,7 @@ _battery_sysctl_start(void)
              bat->model = eina_stringshare_add(battio.bix.model);
              bat->design_charge = battio.bix.dcap;
              bat->last_full_charge = battio.bix.lfcap;
-             bat->poll = ecore_poller_add(ECORE_POLLER_CORE,
-                                          battery_config->poll_interval,
-                                          _battery_sysctl_battery_update_poll, NULL);
+             bat->timer = ecore_timer_add(10.0, _battery_sysctl_battery_update_poll, NULL);
              bat->unit = i;
              device_batteries = eina_list_append(device_batteries, bat);
           }
@@ -154,10 +150,11 @@ _battery_sysctl_stop(void)
         eina_stringshare_del(bat->technology);
         eina_stringshare_del(bat->model);
         eina_stringshare_del(bat->vendor);
-        ecore_poller_del(bat->poll);
+        ecore_timer_del(bat->timer);
 #if defined(__OpenBSD__)
         E_FREE(bat->mib);
 #endif
+        _battery_history_close(bat);
         E_FREE(bat);
      }
 }
@@ -189,9 +186,6 @@ _battery_sysctl_battery_update(Battery *bat)
 
    if (bat)
      {
-       /* update the poller interval */
-       ecore_poller_poller_interval_set(bat->poll,
-                                        battery_config->poll_interval);
 # if defined(__OpenBSD__)
        charge = 0;
 
@@ -237,9 +231,9 @@ _battery_sysctl_battery_update(Battery *bat)
          bat->charge_rate = ((charge - bat->current_charge) / (_time - bat->last_update));
        bat->last_update = _time;
        bat->current_charge = charge;
-       bat->percent = 100 * (bat->current_charge / bat->last_full_charge);
+       bat->percent = (10000 * bat->current_charge) / bat->last_full_charge;
        if (bat->current_charge >= bat->last_full_charge)
-         bat->percent = 100;
+         bat->percent = 10000;
 
        if (bat->got_prop)
          {
@@ -289,7 +283,7 @@ _battery_sysctl_battery_update(Battery *bat)
          }
        bat->got_prop = 1;
 
-       bat->percent = battio.battinfo.cap;
+       bat->percent = battio.battinfo.cap * 100;
        _time = ecore_time_get();
        bat->last_update = _time;
 
