@@ -43,21 +43,12 @@ _devices_eval(void)
         if (o->paired)
           {
              Eina_Bool need_ping = EINA_FALSE;
+             Obj *adapter = bz_obj_find(o->adapter);
 
              dev = _devices_conifg_find(o->address);
-             if (dev)
+             if ((dev) && (adapter) && (adapter->powered))
                {
                   printf("=== dev: %s|%s [%s]\n", dev->addr, o->address, o->name);
-                  if ((dev->force_connect) && (!o->connected))
-                    {
-                       printf("=== %s force con, not conn, ping ok=%i\n", o->address, o->ping_ok);
-                       if (o->ping_ok)
-                         {
-                            printf("=== %s force con, not conn, ping ok=%i\n", o->address, o->ping_ok);
-                            bz_obj_connect(o);
-                         }
-                       else need_ping = EINA_TRUE;
-                    }
                   if (dev->unlock)
                     {
                        printf("=== unlock...\n");
@@ -278,6 +269,7 @@ static void
 _cb_unpair(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    Obj *o = data;
+   ebluez5_device_prop_unlock_set(o-> address, EINA_FALSE);
    bz_obj_remove(o);
    _unflip(o, obj);
 }
@@ -286,7 +278,7 @@ static void
 _cb_unlock_start(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    Obj *o = data;
-   printf("unlock start %s\n", o->address);
+   printf("BZ5: unlock start %s\n", o->address);
    ebluez5_device_prop_unlock_set(o->address, EINA_TRUE);
    ebluez5_popup_device_change(o);
    _unflip(o, obj);
@@ -296,30 +288,12 @@ static void
 _cb_unlock_stop(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    Obj *o = data;
-   printf("unlock stop %s\n", o->address);
+   printf("BZ5: unlock stop %s\n", o->address);
    ebluez5_device_prop_unlock_set(o->address, EINA_FALSE);
    ebluez5_popup_device_change(o);
    _unflip(o, obj);
 }
 
-static void
-_cb_force_connect_start(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
-{
-   Obj *o = data;
-   ebluez5_device_prop_force_connect_set(o->address, EINA_TRUE);
-   ebluez5_popup_adapter_change(o);
-   _unflip(o, obj);
-}
-
-static void
-_cb_force_connect_stop(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
-{
-   Obj *o = data;
-   ebluez5_device_prop_force_connect_set(o->address, EINA_FALSE);
-   ebluez5_popup_adapter_change(o);
-   _unflip(o, obj);
-}
-
 static void
 _cb_flip(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
@@ -567,48 +541,31 @@ _cb_dev_content_get(void *data, Evas_Object *obj,
 
                   if ((dev) && (dev->unlock))
                     {
-                       bt = util_button_icon_add(obj, "changes-allow-symbolic",
+                       bt = util_button_icon_add(obj, "bt-lock-device-off",
                                                  _("Stop this from being an unlock device"));
                        evas_object_data_set(bt, "genlist", obj);
                        evas_object_smart_callback_add(bt, "clicked", _cb_unlock_stop, o);
                     }
                   else
                     {
-                       bt = util_button_icon_add(obj, "channel-insecure-symbolic",
+                       bt = util_button_icon_add(obj, "bt-lock-device-on",
                                                  _("Make this auto unlock when detected (and lock when not)"));
                        evas_object_data_set(bt, "genlist", obj);
                        evas_object_smart_callback_add(bt, "clicked", _cb_unlock_start, o);
                     }
                   elm_box_pack_end(bx, bt);
                   evas_object_show(bt);
-
-                  if ((dev) && (dev->force_connect))
-                    {
-                       bt = util_button_icon_add(obj, "checkbox-symbolic",
-                                                 _("Stop this device from being forcefully connected"));
-                       evas_object_data_set(bt, "genlist", obj);
-                       evas_object_smart_callback_add(bt, "clicked", _cb_force_connect_stop, o);
-                    }
-                  else
-                    {
-                       bt = util_button_icon_add(obj, "checkbox-checked-symbolic",
-                                                 _("Force this device to be connected when detected"));
-                       evas_object_data_set(bt, "genlist", obj);
-                       evas_object_smart_callback_add(bt, "clicked", _cb_force_connect_start, o);
-                    }
-                  elm_box_pack_end(bx, bt);
-                  evas_object_show(bt);
                }
              if (o->connected)
                {
-                  bt = util_button_icon_add(obj, "network-offline",
+                  bt = util_button_icon_add(obj, "bt-connect-off",
                                             _("Disconnect this device"));
                   evas_object_data_set(bt, "genlist", obj);
                   evas_object_smart_callback_add(bt, "clicked", _cb_disconnect, o);
                }
              else
                {
-                  bt = util_button_icon_add(obj, "network-transmit-receive",
+                  bt = util_button_icon_add(obj, "bt-connect-on",
                                             _("Connect this device"));
                   evas_object_data_set(bt, "genlist", obj);
                   evas_object_smart_callback_add(bt, "clicked", _cb_connect, o);
@@ -637,7 +594,7 @@ _cb_dev_content_get(void *data, Evas_Object *obj,
           {
              if (!o->agent_request)
                {
-                  bt = util_button_icon_add(obj, "list-add",
+                  bt = util_button_icon_add(obj, "bt-pair-on",
                                             _("Pair with this device"));
                   evas_object_data_set(bt, "genlist", obj);
                   evas_object_smart_callback_add(bt, "clicked", _cb_pair, o);
@@ -647,7 +604,7 @@ _cb_dev_content_get(void *data, Evas_Object *obj,
           }
         else
           {
-             bt = util_button_icon_add(obj, "list-remove",
+             bt = util_button_icon_add(obj, "bt-pair-off",
                                         _("Unpair with this device"));
              evas_object_data_set(bt, "genlist", obj);
              evas_object_smart_callback_add(bt, "clicked", _cb_unpair, o);
@@ -655,7 +612,7 @@ _cb_dev_content_get(void *data, Evas_Object *obj,
              evas_object_show(bt);
           }
 
-        bt = util_button_icon_add(obj, "view-more-horizontal",
+        bt = util_button_icon_add(obj, "bt-expand-right",
                                   _("Cancel"));
         evas_object_data_set(bt, "genlist", obj);
         evas_object_smart_callback_add(bt, "clicked", _cb_flip, o);
@@ -698,7 +655,7 @@ _cb_dev_content_get(void *data, Evas_Object *obj,
                   elm_box_pack_end(bx, tb);
                   evas_object_show(tb);
 
-                  bt = util_button_icon_add(obj, "list-add",
+                  bt = util_button_icon_add(obj, "bt-pair-ok",
                                             _("Pair with this device"));
                   evas_object_data_set(bt, "genlist", obj);
                   evas_object_data_set(bt, "entry", en);
@@ -706,7 +663,7 @@ _cb_dev_content_get(void *data, Evas_Object *obj,
                   elm_box_pack_end(bx, bt);
                   evas_object_show(bt);
 
-                  bt = util_button_icon_add(obj, "list-remove",
+                  bt = util_button_icon_add(obj, "bt-pair-cancel",
                                             _("Reject pairing"));
                   evas_object_data_set(bt, "genlist", obj);
                   evas_object_smart_callback_add(bt, "clicked", _cb_agent_cancel, o);
@@ -720,14 +677,14 @@ _cb_dev_content_get(void *data, Evas_Object *obj,
                   elm_box_pack_end(bx, lb);
                   evas_object_show(lb);
 
-                  bt = util_button_icon_add(obj, "list-add",
+                  bt = util_button_icon_add(obj, "bt-pair-ok",
                                             _("Pair with this device"));
                   evas_object_data_set(bt, "genlist", obj);
                   evas_object_smart_callback_add(bt, "clicked", _cb_agent_ok, o);
                   elm_box_pack_end(bx, bt);
                   evas_object_show(bt);
 
-                  bt = util_button_icon_add(obj, "list-remove",
+                  bt = util_button_icon_add(obj, "bt-pair-cancel",
                                             _("Reject pairing"));
                   evas_object_data_set(bt, "genlist", obj);
                   evas_object_smart_callback_add(bt, "clicked", _cb_agent_cancel, o);
@@ -736,7 +693,30 @@ _cb_dev_content_get(void *data, Evas_Object *obj,
                }
           }
 
-        bt = util_button_icon_add(obj, "view-more-horizontal",
+        if (o->bat_percent >= 0)
+          {
+             Evas_Object *bat;
+             Edje_Message_Float msg;
+             double level = 0.0;
+             const int size = 24;
+
+             bat = edje_object_add(evas_object_evas_get(obj));
+             e_theme_edje_object_set(bat, "base/theme/modules/battery",
+                                     "e/modules/battery/main");
+             snprintf(buf, sizeof(buf), "%i", o->bat_percent);
+             edje_object_part_text_set(bat, "e.text.reading", buf);
+             level = (double)o->bat_percent / 100.0;
+             if (level > 1.0) level = 1.0;
+             msg.val = level;
+             edje_object_message_send(bat, EDJE_MESSAGE_FLOAT, 1, &msg);
+             evas_object_size_hint_min_set(bat,
+                                           ELM_SCALE_SIZE(size),
+                                           ELM_SCALE_SIZE(size));
+             elm_box_pack_end(bx, bat);
+             evas_object_show(bat);
+          }
+
+        bt = util_button_icon_add(obj, "bt-expand-left",
                                   _("Options for device like connect, pair etc."));
         evas_object_data_set(bt, "genlist", obj);
         evas_object_smart_callback_add(bt, "clicked", _cb_flip, o);
