@@ -261,8 +261,6 @@ E_API E_Module_Api e_modapi = { E_MODULE_API_VERSION, "Conf" };
 E_API void *
 e_modapi_init(E_Module *m)
 {
-   char buf[PATH_MAX];
-
    conf_module = m;
 
    /* add module supplied action */
@@ -276,13 +274,11 @@ e_modapi_init(E_Module *m)
    maug =
      e_int_menus_menu_augmentation_add_sorted("config/0", _("Settings Panel"),
                                               _e_mod_menu_add, NULL, NULL, NULL);
-   snprintf(buf, sizeof(buf), "%s/e-module-conf.edj",
-            e_module_dir_get(conf_module));
 
    e_configure_registry_category_add("advanced", 80, _("Advanced"),
                                      NULL, "preferences-advanced");
    e_configure_registry_item_add("advanced/conf", 110, _("Configuration Panel"),
-                                 NULL, buf, e_int_config_conf_module);
+                                 NULL, "preferences-panel", e_int_config_conf_module);
 
    conf_edd = E_CONFIG_DD_NEW("Config", Config);
 #undef T
@@ -389,56 +385,6 @@ _e_mod_conf_cb(void *data EINA_UNUSED, E_Menu *m EINA_UNUSED, E_Menu_Item *mi EI
    e_configure_show(NULL);
 }
 
-static void
-_e_mod_mode_presentation_toggle(void *data EINA_UNUSED, E_Menu *m EINA_UNUSED, E_Menu_Item *mi)
-{
-   e_config->mode.presentation = !e_config->mode.presentation;
-   e_menu_item_toggle_set(mi, e_config->mode.presentation);
-   e_config_mode_changed();
-   e_config_save_queue();
-}
-
-static void
-_e_mod_mode_offline_toggle(void *data EINA_UNUSED, E_Menu *m EINA_UNUSED, E_Menu_Item *mi)
-{
-   e_config->mode.offline = !e_config->mode.offline;
-   e_menu_item_toggle_set(mi, e_config->mode.offline);
-   e_config_mode_changed();
-   e_config_save_queue();
-}
-
-static void
-_e_mod_submenu_modes_fill(void *data EINA_UNUSED, E_Menu *m)
-{
-   E_Menu_Item *mi;
-
-   mi = e_menu_item_new(m);
-   e_menu_item_check_set(mi, 1);
-   e_menu_item_toggle_set(mi, e_config->mode.presentation);
-   e_menu_item_label_set(mi, _("Presentation"));
-   e_util_menu_item_theme_icon_set(mi, "preferences-modes-presentation");
-   e_menu_item_callback_set(mi, _e_mod_mode_presentation_toggle, NULL);
-
-   mi = e_menu_item_new(m);
-   e_menu_item_check_set(mi, 1);
-   e_menu_item_toggle_set(mi, e_config->mode.offline);
-   e_menu_item_label_set(mi, _("Offline"));
-   e_util_menu_item_theme_icon_set(mi, "preferences-modes-offline");
-   e_menu_item_callback_set(mi, _e_mod_mode_offline_toggle, NULL);
-
-   e_menu_pre_activate_callback_set(m, NULL, NULL);
-}
-
-static E_Menu *
-_e_mod_submenu_modes_get(void)
-{
-   E_Menu *m;
-
-   if (!(m = e_menu_new())) return NULL;
-   e_menu_pre_activate_callback_set(m, _e_mod_submenu_modes_fill, NULL);
-   return m;
-}
-
 /* menu item add hook */
 static void
 _e_mod_menu_add(void *data EINA_UNUSED, E_Menu *m)
@@ -449,12 +395,6 @@ _e_mod_menu_add(void *data EINA_UNUSED, E_Menu *m)
    e_menu_item_label_set(mi, _("Settings Panel"));
    e_util_menu_item_theme_icon_set(mi, "preferences-system");
    e_menu_item_callback_set(mi, _e_mod_conf_cb, NULL);
-
-   mi = e_menu_item_new(m);
-   e_menu_item_label_set(mi, _("Modes"));
-   e_util_menu_item_theme_icon_set(mi, "preferences-modes");
-   e_menu_item_submenu_set(mi, _e_mod_submenu_modes_get());
-   e_object_unref(E_OBJECT(mi->submenu));
 }
 
 static void
