@@ -22,6 +22,7 @@ struct _E_Config_Dialog_Data
    E_Powersave_Mode powersave_min;
    E_Powersave_Mode powersave_max;
    int suspend_connected_standby;
+   int suspend_mode;
 };
 
 E_Config_Dialog *
@@ -58,6 +59,7 @@ _create_data(E_Config_Dialog *cfd EINA_UNUSED)
    cfdata->powersave_high = e_config->powersave.high;
    cfdata->powersave_extreme = e_config->powersave.extreme;
    cfdata->suspend_connected_standby = e_config->suspend_connected_standby;
+   cfdata->suspend_mode = e_config->suspend_mode;
    return cfdata;
 }
 
@@ -73,6 +75,7 @@ static int
 _basic_apply(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
 {
    e_config->suspend_connected_standby = cfdata->suspend_connected_standby;
+   e_config->suspend_mode = cfdata->suspend_mode;
    e_config->powersave.none = cfdata->powersave_none;
    e_config->powersave.low = cfdata->powersave_low;
    e_config->powersave.medium = cfdata->powersave_medium;
@@ -96,6 +99,7 @@ static int
 _basic_check_changed(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
 {
    return ((e_config->suspend_connected_standby != cfdata->suspend_connected_standby) ||
+           (e_config->suspend_mode != cfdata->suspend_mode) ||
            (e_config->powersave.min != cfdata->powersave_min) ||
            (e_config->powersave.max != cfdata->powersave_max) ||
            (!EINA_DBL_EQ(e_config->powersave.none, cfdata->powersave_none)) ||
@@ -109,13 +113,14 @@ static Evas_Object *
 _basic_create(E_Config_Dialog *cfd EINA_UNUSED, Evas *evas, E_Config_Dialog_Data *cfdata)
 {
    Evas_Object *ob, *ol;
-   E_Radio_Group *rmin, *rmax;
+   E_Radio_Group *rmin, *rmax, *smode;
    int y;
 
    cfdata->powersave_min = e_config->powersave.min;
    cfdata->powersave_max = e_config->powersave.max;
    rmin = e_widget_radio_group_new((int*) &(cfdata->powersave_min));
    rmax = e_widget_radio_group_new((int*) &(cfdata->powersave_max));
+   smode = e_widget_radio_group_new((int*) &(cfdata->suspend_mode));
 
    ol = e_widget_table_add(e_win_evas_win_get(evas), 0);
 
@@ -381,6 +386,49 @@ _basic_create(E_Config_Dialog *cfd EINA_UNUSED, Evas *evas, E_Config_Dialog_Data
                                       1, 0,    //expand
                                       0.0, 0.5 //align
                                       );
+   y++;
+   ob = e_widget_label_add(evas,
+                           _("Suspend Mode"));
+   e_widget_table_object_align_append(ol, ob,
+                                      0, y,    //place
+                                      4, 1,    //span
+                                      1, 1,    //fill
+                                      1, 0,    //expand
+                                      0.0, 0.5 //align
+                                      );
+   y++;
+   ob = e_widget_radio_add(evas, "Suspend", 0, smode);
+   if (!e_sys_action_possible_get(E_SYS_SUSPEND))
+     e_widget_disabled_set(ob, EINA_TRUE);
+   e_widget_table_object_align_append(ol, ob,
+                                      0, y,    //place
+                                      4, 1,    //span
+                                      1, 1,    //fill
+                                      1, 0,    //expand
+                                      0.0, 0.5 //align
+                                      );
+   y++;
+   ob = e_widget_radio_add(evas, "Hybrid suspend", 1, smode);
+   if (!e_sys_action_possible_get(E_SYS_HYBRID_SUSPEND))
+     e_widget_disabled_set(ob, EINA_TRUE);
+   e_widget_table_object_align_append(ol, ob,
+                                      0, y,    //place
+                                      4, 1,    //span
+                                      1, 1,    //fill
+                                      1, 0,    //expand
+                                      0.0, 0.5 //align
+                                      );
+   y++;
+   ob = e_widget_radio_add(evas, "Suspend then hibernate", 2, smode);
+   if (!e_sys_action_possible_get(E_SYS_SUSPEND_THEN_HIBERNATE))
+     e_widget_disabled_set(ob, EINA_TRUE);
+   e_widget_table_object_align_append(ol, ob,
+                                      0, y,    //place
+                                      4, 1,    //span
+                                      1, 1,    //fill
+                                      1, 0,    //expand
+                                      0.0, 0.5 //align
+                                      );
    return ol;
 }
 
