@@ -31,6 +31,7 @@ struct _E_Config_Dialog_Data
    Evas_Object *policy_obj;
    int restore;
    int use_cmd;
+   int no_ignore_output;
    int hotplug;
    int acpi;
    int screen;
@@ -105,6 +106,7 @@ _create_data(E_Config_Dialog *cfd EINA_UNUSED)
    if (cfd->data) cfdata->params = strdup(cfd->data);
    cfdata->restore = e_randr2_cfg->restore;
    cfdata->use_cmd = e_randr2_cfg->use_cmd;
+   cfdata->no_ignore_output = !e_randr2_cfg->ignore_output;
    cfdata->hotplug = !e_randr2_cfg->ignore_hotplug_events;
    cfdata->acpi = !e_randr2_cfg->ignore_acpi_events;
    cfdata->policy = e_randr2_cfg->default_policy;
@@ -157,6 +159,14 @@ _cb_use_cmd_changed(void *data EINA_UNUSED, Evas_Object *obj, void *event EINA_U
    e_config_dialog_changed_set(cfdata->cfd, EINA_TRUE);
 }
 
+static void
+_cb_no_ignore_output_changed(void *data EINA_UNUSED, Evas_Object *obj, void *event EINA_UNUSED)
+{
+   E_Config_Dialog_Data *cfdata = data;
+   cfdata->no_ignore_output = elm_check_state_get(obj);
+   e_config_dialog_changed_set(cfdata->cfd, EINA_TRUE);
+}
+
 static void
 _cb_hotplug_changed(void *data EINA_UNUSED, Evas_Object *obj, void *event EINA_UNUSED)
 {
@@ -402,13 +412,18 @@ _basic_screen_info_fill(E_Config_Dialog_Data *cfdata, E_Config_Randr2_Screen *cs
           {
              mode_cbdata->cfdata = cfdata;
              mode_cbdata->mode = *m;
-             if (m->flags & ECORE_X_RANDR_MODE_DOUBLE_SCAN)
+#ifdef E_COMP_X
+             if ((e_comp->comp_type == E_PIXMAP_TYPE_X) &&
+                 (m->flags & ECORE_X_RANDR_MODE_DOUBLE_SCAN))
                snprintf(buf, sizeof(buf), "%ix%i @ %1.2fHz (Doublescan)", m->w, m->h, m->refresh / 2);
+             else if ((e_comp->comp_type == E_PIXMAP_TYPE_X) &&
+                      (m->flags & ECORE_X_RANDR_MODE_INTERLACE))
+               snprintf(buf, sizeof(buf), "%ix%i @ %1.2fHz (Interlaced)", m->w, m->h, m->refresh);
              else
+#endif
                snprintf(buf, sizeof(buf), "%ix%i @ %1.2fHz", m->w, m->h, m->refresh);
              it = elm_list_item_append(cfdata->modes_obj, buf, NULL, NULL, _cb_mode_set, mode_cbdata);
              cfdata->freelist = eina_list_append(cfdata->freelist, mode_cbdata);
-             /* printf("mode add %p %p %p\n", mode_cbdata, cfdata->modes_obj, it); */
              if ((cs->mode_w == m->w) && (cs->mode_h == m->h) &&
                  (fabs(cs->mode_refresh - m->refresh) < 0.01 ))
                it_sel = it;
@@ -773,6 +788,24 @@ _cb_enabled_changed(void *data, Evas_Object *obj, void *event EINA_UNUSED)
    cs->enabled = elm_check_state_get(obj);
    printf("RR: enabled = %i\n", cs->enabled);
    e_config_dialog_changed_set(cfdata->cfd, EINA_TRUE);
+
+   // for every rel_to that points to the disabled screen, set its rel_mode to point to "none"
+   if (!cs->enabled)
+     {
+        Eina_List *l;
+        E_Config_Randr2_Screen *other_cs;
+
+        EINA_LIST_FOREACH(cfdata->screens, l, other_cs)
+          {
+            if (!other_cs) continue;
+            if ((other_cs->rel_to) &&
+                (!strcmp(other_cs->rel_to, cs->id)))
+              {
+                other_cs->rel_mode = E_RANDR2_RELATIVE_NONE;
+                e_config_dialog_changed_set(cfdata->cfd, EINA_TRUE);
+              }
+          }
+     }
 }
 
 static void
@@ -1204,6 +1237,15 @@ _basic_create(E_Config_Dialog *cfd, Evas *evas EINA_UNUSED, E_Config_Dialog_Data
    evas_object_show(o);
    evas_object_smart_callback_add(o, "changed", _cb_use_cmd_changed, cfdata);
 
+   o = elm_check_add(win);
+   evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
+   evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   elm_object_text_set(o, _("Use output"));
+   elm_check_state_set(o, cfdata->no_ignore_output);
+   elm_box_pack_end(bx2, o);
+   evas_object_show(o);
+   evas_object_smart_callback_add(o, "changed", _cb_no_ignore_output_changed, cfdata);
+
    o = elm_check_add(win);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0.0);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
@@ -1249,6 +1291,7 @@ _basic_apply(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
 
    e_randr2_cfg->restore = cfdata->restore;
    e_randr2_cfg->use_cmd = cfdata->use_cmd;
+   e_randr2_cfg->ignore_output = !cfdata->no_ignore_output;
    e_randr2_cfg->ignore_hotplug_events = !cfdata->hotplug;
    e_randr2_cfg->ignore_acpi_events = !cfdata->acpi;
    e_randr2_cfg->default_policy = cfdata->policy;
@@ -1271,12 +1314,15 @@ _basic_apply(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
         printf("APPLY %s .... rel to %s\n", cs->id, cs2->rel_to);
         if (cs2->rel_to) cs->rel_to = eina_stringshare_add(cs2->rel_to);
         cs->rel_align = cs2->rel_align;
-        cs->mode_w = cs2->mode_w;
-        cs->mode_h = cs2->mode_h;
-        cs->mode_refresh = cs2->mode_refresh;
-        cs->rotation = cs2->rotation;
-        cs->priority = cs2->priority;
-        cs->rel_mode = cs2->rel_mode;
+        if (cs2->enabled)
+          {
+             cs->mode_w = cs2->mode_w;
+             cs->mode_h = cs2->mode_h;
+             cs->mode_refresh = cs2->mode_refresh;
+             cs->rotation = cs2->rotation;
+             cs->priority = cs2->priority;
+             cs->rel_mode = cs2->rel_mode;
+          }
         if (cs->custom_label_screen) eina_stringshare_del(cs->custom_label_screen);
         cs->custom_label_screen = NULL;
         if (cs2->custom_label_screen) cs->custom_label_screen = eina_stringshare_add(cs2->custom_label_screen);
