@@ -16,6 +16,7 @@ struct _E_Config_Dialog_Data
    int    use_dpi;
    double min, max, factor;
    int    use_mode, base_dpi, use_custom;
+   int    xapp_base_dpi, set_xapp_dpi;
    struct
    {
       struct
@@ -58,14 +59,12 @@ _scale_preview_sel_set(Evas_Object *ob, int sel)
              cfdata->use_dpi = EINA_TRUE;
              cfdata->use_mode = 1;
              cfdata->use_custom = 0;
-             fprintf(stderr, "custom 0\n");
           }
         else
           {
              cfdata->use_dpi = EINA_FALSE;
              cfdata->use_mode = 2;
              cfdata->use_custom = 1;
-             fprintf(stderr, "custom 1\n");
           }
         EINA_LIST_FOREACH(cfdata->obs, l, ob2)
           {
@@ -206,6 +205,8 @@ _fill_data(E_Config_Dialog_Data *cfdata)
    cfdata->max = e_config->scale.max;
    cfdata->factor = e_config->scale.factor;
    cfdata->base_dpi = e_config->scale.base_dpi;
+   cfdata->xapp_base_dpi = e_config->scale.xapp_base_dpi;
+   cfdata->set_xapp_dpi = e_config->scale.set_xapp_dpi;
 }
 
 static void
@@ -219,30 +220,16 @@ static Evas_Object *
 _basic_create(E_Config_Dialog *cfd EINA_UNUSED, Evas *evas, E_Config_Dialog_Data *cfdata)
 {
    Evas_Object *o, *ob;
-   double sc = 1.0;
-   int dpi = 0, x = 0, y = 0;
+   double sc = 1.0, dpi;
+   int x = 0, y = 0;
 
    _fill_data(cfdata);
    o = e_widget_table_add(e_win_evas_win_get(evas), 1);
 
-#ifndef HAVE_WAYLAND_ONLY
-   if (e_comp->comp_type == E_PIXMAP_TYPE_X)
-     dpi = ecore_x_dpi_get();
-#endif
-#ifdef HAVE_WAYLAND
-   if (e_comp->comp_type == E_PIXMAP_TYPE_WL)
-     {
-        int xdpi = 0, ydpi = 0;
+   dpi = e_scale_dpi_get();
 
-        ecore_evas_screen_dpi_get(e_comp->ee, &xdpi, &ydpi);
-        if (xdpi == 0) xdpi = 75;
-        if (ydpi == 0) ydpi = 75;
-        dpi = ((xdpi + ydpi) / 2);
-     }
-#endif
-
-   if ((dpi > 0) && (cfdata->base_dpi > 0))
-     sc = (double)dpi / (double)cfdata->base_dpi;
+   if ((dpi > 0.0) && (cfdata->base_dpi > 0))
+     sc = dpi / (double)cfdata->base_dpi;
 
    ob = _scale_preview_new(cfdata, evas, sc, &(cfdata->factor), _("DPI Scaling"), EINA_TRUE);
    e_widget_table_object_align_append(o, ob, 0, 0, 1, 1, 0, 0, 0, 0, 0.5, 0.5);
@@ -284,6 +271,8 @@ _basic_apply(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
    e_config->scale.max = cfdata->max;
    e_config->scale.factor = cfdata->factor;
    e_config->scale.base_dpi = cfdata->base_dpi;
+   e_config->scale.xapp_base_dpi = cfdata->xapp_base_dpi;
+   e_config->scale.set_xapp_dpi = cfdata->set_xapp_dpi;
 
    fprintf(stderr, "dpi: %i, custom: %i, min: %3.3f, max: %3.3f, sc: %3.3f: base: %i\n",
            e_config->scale.use_dpi, e_config->scale.use_custom,
@@ -322,38 +311,35 @@ _adv_create(E_Config_Dialog *cfd EINA_UNUSED, Evas *evas, E_Config_Dialog_Data *
    e_widget_on_change_hook_set(ow, _adv_policy_changed, cfdata);
    e_widget_list_object_append(o, ow, 1, 1, 0.5);
 
-#ifndef HAVE_WAYLAND_ONLY
-   if (e_comp->comp_type == E_PIXMAP_TYPE_X)
-     dpi = ecore_x_dpi_get();
-#endif
-#ifdef HAVE_WAYLAND
-   if (e_comp->comp_type == E_PIXMAP_TYPE_WL)
-     {
-        int xdpi = 0, ydpi = 0;
-
-        ecore_evas_screen_dpi_get(e_comp->ee, &xdpi, &ydpi);
-        if (xdpi == 0) xdpi = 75;
-        if (ydpi == 0) ydpi = 75;
-        dpi = ((xdpi + ydpi) / 2);
-     }
-#endif
+   dpi = e_scale_dpi_get();
 
    snprintf(buff, sizeof(buff), _("Base DPI (Currently %i DPI)"), dpi);
 
    ow = e_widget_label_add(evas, buff);
    cfdata->gui.adv.dpi_lbl = ow;
    e_widget_list_object_append(o, ow, 1, 1, 0.5);
-   ow = e_widget_slider_add(evas, 1, 0, _("%1.0f DPI"), 30, 600, 1, 0,
+   ow = e_widget_slider_add(evas, 1, 0, _("%1.0f DPI"), 20, 1000, 1, 0,
                             NULL, &(cfdata->base_dpi), 100);
    cfdata->gui.adv.dpi_slider = ow;
    e_widget_list_object_append(o, ow, 1, 1, 0.5);
    ow = e_widget_radio_add(evas, _("Custom scaling factor"), 2, rg);
    e_widget_on_change_hook_set(ow, _adv_policy_changed, cfdata);
    e_widget_list_object_append(o, ow, 1, 1, 0.5);
-   ow = e_widget_slider_add(evas, 1, 0, _("%1.2f x"), 0.25, 8.0, 0.05,
+   ow = e_widget_slider_add(evas, 1, 0, _("%1.2f x"), 0.25, 8.0, 0.01,
                             0, &(cfdata->factor), NULL, 100);
    cfdata->gui.adv.custom_slider = ow;
    e_widget_list_object_append(o, ow, 1, 1, 0.5);
+
+   ow = e_widget_check_add(evas, _("Set Application DPI"),
+                           &(cfdata->set_xapp_dpi));
+   e_widget_list_object_append(o, ow, 1, 1, 0.5);
+
+   ow = e_widget_label_add(evas, _("Application Base DPI"));
+   e_widget_list_object_append(o, ow, 1, 1, 0.5);
+   ow = e_widget_slider_add(evas, 1, 0, _("%1.0f DPI"), 20, 1000, 1, 0,
+                            NULL, &(cfdata->xapp_base_dpi), 100);
+   e_widget_list_object_append(o, ow, 1, 1, 0.5);
+
    e_widget_toolbook_page_append(otb, NULL, _("Policy"), o,
                                  1, 0, 1, 0, 0.5, 0.0);
 
@@ -399,6 +385,8 @@ _adv_apply(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
    e_config->scale.max = cfdata->max;
    e_config->scale.factor = cfdata->factor;
    e_config->scale.base_dpi = cfdata->base_dpi;
+   e_config->scale.xapp_base_dpi = cfdata->xapp_base_dpi;
+   e_config->scale.set_xapp_dpi = cfdata->set_xapp_dpi;
 
    e_win_no_reopen_set(cfd->dia->win, 1);
    e_remember_update(e_win_client_get(cfd->dia->win));
@@ -425,7 +413,9 @@ _adv_changed(E_Config_Dialog *cfd EINA_UNUSED, E_Config_Dialog_Data *cfdata)
           (!EINA_DBL_EQ(cfdata->min, e_config->scale.min)) ||
           (!EINA_DBL_EQ(cfdata->max, e_config->scale.max)) ||
           (!EINA_DBL_EQ(cfdata->factor, e_config->scale.factor)) ||
-          (cfdata->base_dpi != e_config->scale.base_dpi);
+          (cfdata->base_dpi != e_config->scale.base_dpi) ||
+          (cfdata->xapp_base_dpi != e_config->scale.xapp_base_dpi) ||
+          (e_config->scale.set_xapp_dpi != cfdata->set_xapp_dpi);
 }
 
 static void
