@@ -24,7 +24,7 @@ typedef enum
    E_DESKLOCK_AUTH_METHOD_LINES = 4,
 } E_Desklock_Auth_Method2;
 
-EINTERN Eina_Bool lokker_lock(void);
+EINTERN Eina_Bool lokker_lock(Eina_Bool immediate);
 EINTERN void lokker_unlock(void);
 E_API E_Config_Dialog *e_int_config_lokker(Evas_Object *parent, const char *params EINA_UNUSED);
 EINTERN Eina_Bool lokker_key_down(Ecore_Event_Key*);
