@@ -779,7 +779,10 @@ _source_output_cb(pa_context *c EINA_UNUSED, const pa_source_output_info *info,
    if (eol > 0)
       return;
 
-   if ((info->name) && (!strcmp(info->name, "__e_mon"))) return;
+   if ((info->name) &&
+       ((!strcmp(info->name, "__e_mon")) ||
+        (!strcmp(info->name, "Peak detect"))))
+     return;
 
    output = calloc(1, sizeof(Source_Output));
    EINA_SAFETY_ON_NULL_RETURN(output);
@@ -1534,7 +1537,7 @@ _pulse_connect(void *data)
    return ret;
 }
 
-static Eina_Bool pulse_started;
+static Eina_Bool pulse_started = EINA_FALSE;
 
 static void
 _shutdown(void)
@@ -1580,7 +1583,7 @@ _init(Emix_Event_Cb cb, const void *data)
      {
         if (!pulse_started)
           ecore_exe_run("pulseaudio --start", NULL);
-        pulse_started = 1;
+        pulse_started = EINA_TRUE;
      }
 
    ctx->cb = cb;
