@@ -3,27 +3,6 @@
 
 #include "e.h"
 
-#ifdef HAVE_EEZE
-# include <Eeze.h>
-#endif
-
-
-typedef enum _Sensor_Type
-{
-   SENSOR_TYPE_NONE,
-   SENSOR_TYPE_FREEBSD,
-   SENSOR_TYPE_OPENBSD,
-   SENSOR_TYPE_OMNIBOOK,
-   SENSOR_TYPE_LINUX_MACMINI,
-   SENSOR_TYPE_LINUX_I2C,
-   SENSOR_TYPE_LINUX_ACPI,
-   SENSOR_TYPE_LINUX_PCI,
-   SENSOR_TYPE_LINUX_PBOOK,
-   SENSOR_TYPE_LINUX_INTELCORETEMP,
-   SENSOR_TYPE_LINUX_THINKPAD,
-   SENSOR_TYPE_LINUX_SYS
-} Sensor_Type;
-
 typedef struct _Config Config;
 typedef struct _Config_Face Config_Face;
 typedef struct _Tempthread Tempthread;
@@ -38,14 +17,8 @@ struct _Tempthread
 {
    Config_Face *inst;
    int poll_interval;
-   Sensor_Type sensor_type;
    const char *sensor_name;
-   const char *sensor_path;
-   void *extn;
    E_Powersave_Sleeper *sleeper;
-#ifdef HAVE_EEZE
-   Eina_List *tempdevs;
-#endif
    Eina_Bool initted E_BITFIELD;
 };
 
@@ -62,11 +35,6 @@ struct _Config_Face
    /* config state */
    E_Gadcon_Client *gcc;
    Evas_Object *o_temp;
-#ifdef HAVE_EEZE
-   Ecore_Poller *poller;
-   Tempthread *tth;
-   int backend;
-#endif
    E_Module *module;
 
    E_Config_Dialog *config_dialog;
@@ -84,16 +52,6 @@ struct _Config
    E_Module *module;
 };
 
-#ifdef HAVE_EEZE
-typedef enum _Backend
-{
-   TEMPGET,
-   UDEV
-} Backend;
-
-int temperature_udev_get(Tempthread *tth);
-#endif
-
 E_API extern E_Module_Api e_modapi;
 
 E_API void *e_modapi_init(E_Module *m);
@@ -103,7 +61,16 @@ E_API int e_modapi_save(E_Module *m);
 void config_temperature_module(Config_Face *inst);
 void temperature_face_update_config(Config_Face *inst);
 
-int temperature_tempget_get(Tempthread *tth);
+typedef struct
+{
+   const char *name;
+   const char *label;
+} Sensor;
+
+int        temperature_tempget_get(Tempthread *tth);
+Eina_List *temperature_tempget_sensor_list(void);
+void       temperature_tempget_setup(void);
+void       temperature_tempget_clear(void);
 
 /**
  * @addtogroup Optional_Gadgets
